import { OnDestroy, OnInit } from '@angular/core';
import { MatDialog } from '@angular/material/dialog';
import { MatSnackBar } from '@angular/material/snack-bar';
import { Store } from '@ngrx/store';
import Feature from 'ol/Feature';
import LineString from 'ol/geom/LineString';
import Point from 'ol/geom/Point';
import Polygon from 'ol/geom/Polygon';
import VectorLayer from 'ol/layer/Vector';
import VectorSource from 'ol/source/Vector';
import { Observable, Subscription } from 'rxjs';
import { MangolLayer } from '../../../../classes/Layer';
import { FeatureinfoDictionary } from './../../../../store/featureinfo/featureinfo.reducers';
import * as fromMangol from './../../../../store/mangol.reducers';
import { FeatureinfoService } from './../../featureinfo.service';
export declare class FeatureinfoResultsComponent implements OnInit, OnDestroy {
    private store;
    private featureinfoService;
    snackBar: MatSnackBar;
    dialog: MatDialog;
    dictionary: FeatureinfoDictionary;
    layer$: Observable<MangolLayer>;
    resultsLayer$: Observable<VectorLayer<VectorSource<LineString | Polygon | Point>>>;
    resultsFeatures$: Observable<Feature<LineString | Polygon | Point>[]>;
    tab$: Observable<string>;
    combinedSubscription: Subscription;
    clickFunction: any;
    constructor(store: Store<fromMangol.MangolState>, featureinfoService: FeatureinfoService, snackBar: MatSnackBar, dialog: MatDialog);
    ngOnInit(): void;
    ngOnDestroy(): void;
    /**
     * Removes the click funciton if needed, plus resets the cursor style
     */
    private _removeClickFunction;
    /**
     * Creates the clickFunction for a given singleclick event
     * @param evt
     * @param layer
     * @param m
     */
    private _createClickFunction;
    /**
     * Opens a snackbar with the number of features found
     * @param hits
     */
    private _openSnackBar;
    /**
     * Retrieves the title for the individual feature
     * @param feature
     */
    getExpansionPanelTitle$(feature: Feature<LineString | Polygon | Point>): Observable<string>;
    /**
     * Opens a full table dialog
     */
    openTableDialog(): void;
    /**
     * Shows the feature on the map with a hover style
     * @param feature
     */
    showFeatureOnMap(feature: Feature<LineString | Polygon | Point>): void;
    /**
     * Hides the hovered feature on the map
     * @param feature
     */
    hideFeatureOnMap(feature: Feature<LineString | Polygon | Point>): void;
    /**
     * Sets the view extent to a feature
     * @param feature
     */
    zoomToFeature(feature: Feature<LineString | Polygon | Point>): void;
}
